==> pf_onesignal-2.1.0.tar.gz: pf_onesignal/src/Controller/Register.php <==
<?php

namespace Drupal\pf_onesignal\Controller;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Access\AccessResultInterface;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\pf_onesignal\Entity\Device;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;

/**
 * Endpoint to receive OneSignal device registration.
 */
class Register extends ControllerBase {

  /**
   * @var \Symfony\Component\HttpFoundation\Request
   */
  protected $request;

  /**
   * Register constructor.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   * @param \Drupal\Core\Session\AccountInterface $account
   * @param \Symfony\Component\HttpFoundation\Request $request
   */
  public function __construct(EntityTypeManagerInterface $entityTypeManager, AccountInterface $account, Request $request) {
    $this->entityTypeManager = $entityTypeManager;
    $this->currentUser = $account;
    $this->request = $request;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager'),
      $container->get('current_user'),
      $container->get('request_stack')->getCurrentRequest()
    );
  }

  /**
   * @return \Drupal\Core\StringTranslation\TranslatableMarkup
   */
  public function title(): TranslatableMarkup {
    return $this->t('System endpoint');
  }

  /**
   * @return \Drupal\Core\Access\AccessResultInterface
   */
  public function access(): AccessResultInterface {
    if ($this->currentUser()->isAuthenticated()) {
      return AccessResult::allowed();
    }
    return AccessResult::forbidden();
  }

  /**
   * @return \Symfony\Component\HttpFoundation\Response
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  public function execute(): Response {
    $info = json_decode($this->request->getContent(), TRUE);
    if (!isset($info['oneSignalUserId'])) {
      return new Response('Bad request', 400);
    }
    $ids = $this->entityTypeManager()->getStorage('onesignal_device')
      ->getQuery()
      ->condition('onesignaluserid', $info['oneSignalUserId'])
      ->condition('uid', $this->currentUser()->id())
      ->execute();
    if (empty($ids)) {
      $device = Device::create([
        'onesignaluserid' => $info['oneSignalUserId'],
        'uid' => $this->currentUser()->id(),
      ]);
    }
    else {
      $device = Device::load(reset($ids));
    }
    $fields = [
      'appversion' => 'appVersion',
      'os' => 'os',
      'language' => 'language',
      'platform' => 'platform',
      'osversion' => 'osVersion',
      'model' => 'model',
      'onesignaluserid' => 'oneSignalUserId',
    ];
    $changed = FALSE;
    foreach ($fields as $key => $value) {
      if (isset($info[$value]) && $device->get($key)->value !== $info[$value]) {
        $changed = TRUE;
        $device->set($key, $info[$value]);
      }
    }
    if ($changed) {
      $device->save();
    }
    return new Response('thx');
  }

}

==> pf_onesignal-2.1.1.tar.gz: pf_onesignal/src/Controller/Register.php <==
<?php

namespace Drupal\pf_onesignal\Controller;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Access\AccessResultInterface;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\pf_onesignal\Entity\Device;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;

/**
 * Endpoint to receive OneSignal device registration.
 */
class Register extends ControllerBase {

  /**
   * The current request.
   *
   * @var \Symfony\Component\HttpFoundation\Request
   */
  protected Request $request;

  /**
   * Register constructor.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   *   The entity type manager.
   * @param \Drupal\Core\Session\AccountInterface $account
   *   The current use account.
   * @param \Symfony\Component\HttpFoundation\Request $request
   *   The current request.
   */
  public function __construct(EntityTypeManagerInterface $entityTypeManager, AccountInterface $account, Request $request) {
    $this->entityTypeManager = $entityTypeManager;
    $this->currentUser = $account;
    $this->request = $request;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): Register {
    return new static(
      $container->get('entity_type.manager'),
      $container->get('current_user'),
      $container->get('request_stack')->getCurrentRequest()
    );
  }

  /**
   * Get the title of this controller.
   *
   * @return \Drupal\Core\StringTranslation\TranslatableMarkup
   *   The title.
   */
  public function title(): TranslatableMarkup {
    return $this->t('System endpoint');
  }

  /**
   * Check access to this controller for the current user.
   *
   * @return \Drupal\Core\Access\AccessResultInterface
   *   The access result.
   */
  public function access(): AccessResultInterface {
    if ($this->currentUser()->isAuthenticated()) {
      return AccessResult::allowed();
    }
    return AccessResult::forbidden();
  }

  /**
   * Execute this controller and build response.
   *
   * @return \Symfony\Component\HttpFoundation\Response
   *   The response.
   *
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   * @throws \Drupal\Core\Entity\EntityStorageException
   * @throws \JsonException
   */
  public function execute(): Response {
    $info = json_decode($this->request->getContent(), TRUE, 512, JSON_THROW_ON_ERROR);
    if (!isset($info['oneSignalUserId'])) {
      return new Response('Bad request', 400);
    }
    $ids = $this->entityTypeManager()->getStorage('onesignal_device')
      ->getQuery()
      ->condition('onesignaluserid', $info['oneSignalUserId'])
      ->condition('uid', $this->currentUser()->id())
      ->execute();
    if (empty($ids)) {
      $device = Device::create([
        'onesignaluserid' => $info['oneSignalUserId'],
        'uid' => $this->currentUser()->id(),
      ]);
    }
    else {
      $device = Device::load(reset($ids));
    }
    $fields = [
      'appversion' => 'appVersion',
      'os' => 'os',
      'language' => 'language',
      'platform' => 'platform',
      'osversion' => 'osVersion',
      'model' => 'model',
      'onesignaluserid' => 'oneSignalUserId',
    ];
    $changed = FALSE;
    foreach ($fields as $key => $value) {
      if (isset($info[$value]) && $device->get($key)->value !== $info[$value]) {
        $changed = TRUE;
        $device->set($key, $info[$value]);
      }
    }
    if ($changed) {
      $device->save();
    }
    return new Response('thx');
  }

}
